videocollection/hgmyvideos/inc/vcxhgmyvideoscategorymodelhandler.h
branchRCL_3
changeset 13 112a725ff2c2
parent 10 ce5ada96ab30
child 14 8970fbd719ec
--- a/videocollection/hgmyvideos/inc/vcxhgmyvideoscategorymodelhandler.h	Mon Mar 15 12:40:47 2010 +0200
+++ b/videocollection/hgmyvideos/inc/vcxhgmyvideoscategorymodelhandler.h	Wed Mar 31 21:34:36 2010 +0300
@@ -34,6 +34,7 @@
 class CMPXMedia;
 class CMyVideosIndicator;
 class CVcxHgMyVideosThumbnailManager;
+class TAknsItemID;
 
 // ENUMERATIONS
 enum TVcxHgMyVideosCategoryItemType
@@ -328,12 +329,14 @@
         /**
          * Create hg list icon from file
          * 
+         * @param aSkinId Skin-Id of the icon
          * @param aFileName mif file name
          * @param aBitmapId bitmap index in mif file
          * @param aMaskId mask index in mif file
          * @return Icon
          */
         CGulIcon* CreateHgListIconL(
+                const TAknsItemID& aSkinId,
                 const TFileName& aFileName,
                 TInt aBitmapId,
                 TInt aMaskId );
@@ -328,12 +329,14 @@
          * @param aFileName mif file name
-         * @param aBitmapId bitmap index in mif file
-         * @param aMaskId mask index in mif file
+         * @param aBitmapId bitmap index in mif file (used if skin-Id is not found)
+         * @param aMaskId mask index in mif file (used if skin-Id is not found)
          * @return Icon
          */